OC.L10N.register(
    "core",
    {
    "Please select a file." : "Wybierz plik.",
    "File is too big" : "Plik jest za duży",
    "The selected file is not an image." : "Wybrany plik nie jest obrazem.",
    "The selected file cannot be read." : "Wybrany plik nie może być odczytany.",
    "The file was uploaded" : "Plik został wysłany",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Wysłany plik przekracza wartość upload_max_filesize zdefiniowaną w php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Wysłany plik przekracza wartość MAX_FILE_SIZE określoną w formularzu HTML",
    "The file was only partially uploaded" : "Plik został wysłany tylko częściowo",
    "No file was uploaded" : "Nie wysłano żadnego pliku",
    "Missing a temporary folder" : "Brak katalogu tymczasowego",
    "Could not write file to disk" : "Nie można zapisać pliku na dysku",
    "A PHP extension stopped the file upload" : "Rozszerzenie PHP zatrzymało wysyłanie pliku",
    "Invalid file provided" : "Wskazano nieprawidłowy plik",
    "No image or file provided" : "Brak obrazu lub pliku",
    "Unknown filetype" : "Nieznany typ pliku",
    "An error occurred. Please contact your admin." : "Wystąpił błąd. Skontaktuj się z administratorem.",
    "Invalid image" : "Nieprawidłowy obraz",
    "State token does not match" : "Token nie pasuje",
    "Invalid app password" : "Nieprawidłowe hasło do aplikacji",
    "Could not complete login" : "Nie można dokończyć logowania",
    "State token missing" : "Brak statusu tokena",
    "Your login token is invalid or has expired" : "Token logowania jest nieprawidłowy lub wygasł",
    "Please use original client" : "Użyj oryginalnego klienta",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "To wydanie społecznościowe Nextcloud nie jest obsługiwane, a powiadomienia Push są ograniczone.",
    "Login" : "Zaloguj",
    "Unsupported email length (>255)" : "Nieobsługiwana długość wiadomości e-mail (>255)",
    "Password reset is disabled" : "Resetowanie hasła jest wyłączone",
    "Could not reset password because the token is expired" : "Nie można zresetować hasła, ponieważ token wygasł",
    "Could not reset password because the token is invalid" : "Nie można zresetować hasła, ponieważ token jest nieprawidłowy",
    "Password is too long. Maximum allowed length is 469 characters." : "Hasło jest za długie. Maksymalna dozwolona długość to 469 znaków.",
    "%s password reset" : "%s zresetowanie hasła",
    "Password reset" : "Zresetowanie hasła",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Kliknij w przycisk, aby zresetować hasło. Jeśli nie zażądałeś zresetowania hasła, zignoruj tego e-maila.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Kliknij poniższy link, aby zresetować hasło. Jeśli nie zażądałeś zresetowania hasła, zignoruj tego e-maila.",
    "Reset your password" : "Zresetuj hasło",
    "The given provider is not available" : "Podany dostawca jest niedostępny",
    "Task not found" : "Nie znaleziono zadania",
    "Internal error" : "Błąd wewnętrzny",
    "Not found" : "Nie znaleziono",
    "Node is locked" : "Węzeł jest zablokowany",
    "Bad request" : "Złe żądanie",
    "Input text is too long" : "Wprowadzony tekst jest zbyt długi",
    "Requested task type does not exist" : "Żądany typ zadania nie istnieje",
    "Necessary language model provider is not available" : "Niezbędny dostawca modelu językowego nie jest dostępny",
    "Cannot generate more than 12 images" : "Nie można wygenerować więcej niż 12 obrazów",
    "Cannot generate less than 1 image" : "Nie można wygenerować mniej niż 1 obraz",
    "No text to image provider is available" : "Brak dostępnego dostawcy tekstu na obraz",
    "Image not found" : "Nie znaleziono obrazu",
    "No translation provider available" : "Brak dostępnego dostawcy tłumaczenia",
    "Could not detect language" : "Nie można wykryć języka",
    "Unable to translate" : "Nie można przetłumaczyć",
    "No valid filters provided" : "Nie podano prawidłowych filtrów",
    "[%d / %d]: %s" : "[%d/%d]: %s",
    "Repair step:" : "Krok naprawy:",
    "Repair info:" : "Informacja o naprawie: ",
    "Repair warning:" : "Ostrzeżenie naprawy:",
    "Repair error:" : "Błąd naprawy: ",
    "Nextcloud Server" : "Serwer Nextcloud",
    "Some of your link shares have been removed" : "Niektóre udostępnienia linków zostały usunięte",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Ze względu na błąd bezpieczeństwa musieliśmy usunąć część Twoich udostępnień linków. Zobacz link, aby uzyskać więcej informacji.",
    "The account limit of this instance is reached." : "Osiągnięto limit ilości kont tej instancji.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Wprowadź klucz subskrypcji w aplikacji pomocy technicznej, aby zwiększyć limit kont. Zapewnia to również wszystkie dodatkowe korzyści oferowane przez Nextcloud dla firm i jest wysoce zalecane dla działania w firmach.",
    "Learn more ↗" : "Dowiedz się więcej ↗",
    "Preparing update" : "Przygotowywanie aktualizacji",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Użyj wiersza poleceń do aktualizacji, ponieważ aktualizacja przez przeglądarkę jest wyłączona w Twoim pliku config.php.",
    "Turned on maintenance mode" : "Włączono tryb konserwacji",
    "Turned off maintenance mode" : "Wyłączono tryb konserwacji",
    "Maintenance mode is kept active" : "Tryb konserwacji pozostał aktywny",
    "Updating database schema" : "Aktualizacja struktury bazy danych",
    "Updated database" : "Zaktualizowano bazę danych",
    "Update app \"%s\" from App Store" : "Aktualizacja aplikacji \"%s\" ze sklepu z aplikacjami",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Sprawdzanie, czy można zaktualizować strukturę bazy danych dla %s (może to zająć dużo czasu w zależności od rozmiaru bazy danych)",
    "Updated \"%1$s\" to %2$s" : "Aktualizacja \"%1$s\" do %2$s",
    "Set log level to debug" : "Ustawienie poziomu dziennika do debugowania",
    "Reset log level" : "Zresetowanie poziomu dziennika",
    "Starting code integrity check" : "Rozpoczęcie sprawdzania integralności kodu",
    "Finished code integrity check" : "Zakończono sprawdzanie integralności kodu",
    "%s (incompatible)" : "%s (niekompatybilny)",
    "The following apps have been disabled: %s" : "Następujące aplikacje zostały wyłączone: %s",
    "Already up to date" : "Już zaktualizowano",
    "Windows Command Script" : "Skrypt poleceń Windows",
    "Electronic book document" : "Dokument książki elektronicznej",
    "TrueType Font Collection" : "Kolekcja czcionek TrueType",
    "Web Open Font Format" : "Format czcionki Web Open (WOFF)",
    "GPX geographic data" : "Dane geograficzne GPX",
    "Gzip archive" : "Archiwum Gzip",
    "Adobe Illustrator document" : "Dokument Adobe Illustrator",
    "Java source code" : "Kod źródłowy Java",
    "JavaScript source code" : "Kod źródłowy JavaScript",
    "JSON document" : "Dokument JOSN",
    "Microsoft Access database" : "Baza danych Microsoft Access",
    "Microsoft OneNote document" : "Dokument Microsoft OneNote",
    "Microsoft Word document" : "Dokument Microsoft Word",
    "Unknown" : "Nieznany",
    "PDF document" : "Dokument PDF",
    "PostScript document" : "Dokument PostScript",
    "RSS summary" : "Podsumowanie RSS",
    "Android package" : "Pakiet Android (APK)",
    "KML geographic data" : "Dane geograficzne KML",
    "KML geographic compressed data" : "Skompresowane dane geograficzne KML",
    "Lotus Word Pro document" : "Dokument Lotus Word Pro",
    "Excel spreadsheet" : "Arkusz kalkulacyjny Excel",
    "Excel add-in" : "Wtyczka Excel",
    "Excel 2007 binary spreadsheet" : "Binarny arkusz kalkulacyjny Excel 2007",
    "Excel spreadsheet template" : "Szablon arkusza kalkulacyjnego Excel",
    "Outlook Message" : "Wiadomość Outlook",
    "PowerPoint presentation" : "Prezentacja PowerPoint",
    "PowerPoint add-in" : "Wtyczka PowerPoint",
    "PowerPoint presentation template" : "Szablon prezentacji PowerPoint",
    "Word document" : "Dokument Word",
    "ODF formula" : "Formuła ODF",
    "ODG drawing" : "Rysunek ODG",
    "ODG drawing (Flat XML)" : "Rysunek ODG (płaski XML)",
    "ODG template" : "Szablon ODG",
    "ODP presentation" : "Prezentacja ODP",
    "ODP presentation (Flat XML)" : "Prezentacja ODP (płaski XML)",
    "ODP template" : "Szablon ODT",
    "ODS spreadsheet" : "Arkusz kalkulacyjny ODS",
    "ODS spreadsheet (Flat XML)" : "Arkusz kalkulacyjny ODS (płaski XML)",
    "ODS template" : "Szablon ODS",
    "ODT document" : "Dokument ODT",
    "ODT document (Flat XML)" : "Dokument ODT (płaski XML)",
    "ODT template" : "Szablon ODT",
    "PowerPoint 2007 presentation" : "Prezentacja PowerPoint 2007",
    "PowerPoint 2007 show" : "Pokaz PowerPoint 2007",
    "PowerPoint 2007 presentation template" : "Szablon prezentacji PowerPoint 2007",
    "Excel 2007 spreadsheet" : "Arkusz kalkulacyjny Excel 2007",
    "Excel 2007 spreadsheet template" : "Szablon arkusza kalkulacyjnego Excel 2007",
    "Word 2007 document" : "Dokument Word 2007",
    "Word 2007 document template" : "Szablon dokumentu Word 2007",
    "Microsoft Visio document" : "Dokument Microsoft Visio",
    "WordPerfect document" : "Dokument WordPerfect ",
    "7-zip archive" : "Archiwum 7-zip",
    "Blender scene" : "Scena Blender",
    "Bzip2 archive" : "Archiwum Bzip2",
    "Debian package" : "Pakiet Debian (DEB)",
    "FictionBook document" : "Dokument FictionBook",
    "Unknown font" : "Nieznana czcionka",
    "Krita document" : "Dokument Krita",
    "Mobipocket e-book" : "E-book Mobipocket ",
    "Windows Installer package" : "Pakiet instalacyjny Windows (MSI)",
    "Perl script" : "Skrypt Perl",
    "PHP script" : "Skrypt PHP",
    "Tar archive" : "Archiwum Tar",
    "XML document" : "Dokument XML",
    "YAML document" : "Dokument YAML",
    "Zip archive" : "Archiwum ZIP",
    "Zstandard archive" : "Archiwum Zstandard",
    "AAC audio" : "Dźwięk AAC",
    "FLAC audio" : "Dźwięk FLAC",
    "MPEG-4 audio" : "Dźwięk MPEG-4",
    "MP3 audio" : "Dźwięk MP3",
    "Ogg audio" : "Dźwięk Ogg",
    "RIFF/WAVe standard Audio" : "Dźwięk w standardzie RIFF/WAVe",
    "WebM audio" : "Dźwięk WebM",
    "MP3 ShoutCast playlist" : "Playlista MP3 ShoutCast",
    "Windows BMP image" : "Obraz Windows BMP",
    "Better Portable Graphics image" : "Obraz Better Portable Graphics (BPG)",
    "EMF image" : "Obraz EMF",
    "GIF image" : "Obraz GIF",
    "HEIC image" : "Obraz HEIC ",
    "HEIF image" : "Obraz HEIF ",
    "JPEG-2000 JP2 image" : "Obraz JPEG-2000 JP2",
    "JPEG image" : "Obraz JPEG",
    "PNG image" : "obraz PNG",
    "SVG image" : "Obraz SVG",
    "Truevision Targa image" : "Obraz Truevision Targa (TGA)",
    "TIFF image" : "Obraz TIFF",
    "WebP image" : "Obraz WebP",
    "Digital raw image" : "Cyfrowy obraz w formacie RAW",
    "Windows Icon" : "Ikona Windows",
    "Email message" : "Wiadomość email",
    "VCS/ICS calendar" : "Kalendarz VCS/ICS",
    "CSS stylesheet" : "Arkusz stylów CSS",
    "CSV document" : "Dokument CSV",
    "HTML document" : "Dokument HTML",
    "Markdown document" : "Dokument Markdown",
    "Org-mode file" : "Plik w formacie Org-mode",
    "Plain text document" : "Dokument tekstowy (zwykły tekst)",
    "Rich Text document" : "Dokument Rich Text (RTF)",
    "Electronic business card" : "Elektroniczna wizytówka",
    "C++ source code" : "Kod źródłowy C++",
    "LDIF address book" : "Książka adresowa LDIF",
    "NFO document" : "Dokument NFO",
    "PHP source" : "Źródło PHP",
    "Python script" : "Skrypt Python",
    "ReStructuredText document" : "Dokument ReStructuredText",
    "3GPP multimedia file" : "Plik multimedialny 3GPP",
    "MPEG video" : "Wideo MPEG",
    "DV video" : "Wideo DV",
    "MPEG-2 transport stream" : "Strumień transportowy MPEG-2",
    "MPEG-4 video" : "Wideo MPEG-4",
    "Ogg video" : "Wideo Ogg",
    "QuickTime video" : "Wideo QuickTime",
    "WebM video" : "Wideo WebM",
    "Flash video" : "Wideo Flash",
    "Matroska video" : "Wideo Matroska",
    "Windows Media video" : "Wideo Windows Media",
    "AVI video" : "Wideo AVI",
    "Done" : "Gotowe",
    "Scan QR code to log in" : "Zeskanuj kod QR, aby się zalogować",
    "Use {productName} mobile client you want to connect to scan the code" : "Użyj klienta mobilnego {productName}, z którym chcesz się połączyć, aby zeskanować kod",
    "Code will expire {timeCountdown} or after use" : "Kod wygaśnie za {timeCountdown} lub po użyciu",
    "Applications menu" : "Menu aplikacji",
    "Apps" : "Aplikacje",
    "More apps" : "Więcej aplikacji",
    "_{count} notification_::_{count} notifications_" : ["{count} powiadomienie","{count} powiadomienia","{count} powiadomień","{count} powiadomień"],
    "No" : "Nie",
    "Yes" : "Tak",
    "App password" : "Hasło aplikacji",
    "Grant access" : "Udziel dostępu",
    "The remote URL must include the user." : "Zdalny adres URL musi zawierać nazwę użytkownika.",
    "Invalid remote URL." : "Nieprawidłowy zdalny adres URL.",
    "Failed to add the public link to your Nextcloud" : "Nie udało się dodać linku publicznego do Nextcloud",
    "Federated user" : "Użytkownik sfederowany",
    "user@your-nextcloud.org" : "uzytkownik@twoj-nextcloud.pl",
    "Create share" : "Utwórz udostępnienie",
    "Direct link copied" : "Bezpośredni link skopiowany",
    "Please copy the link manually:" : "Skopiuj odnośnik ręcznie:",
    "Custom date range" : "Własny zakres dat",
    "Pick start date" : "Wybierz datę rozpoczęcia",
    "Pick end date" : "Wybierz datę zakończenia",
    "Search in date range" : "Szukaj w zakresie dat",
    "Search in current app" : "Wyszukaj w bieżącej aplikacji",
    "Clear search" : "Wyczyść wyszukiwanie",
    "Search everywhere" : "Szukaj wszędzie",
    "Searching …" : "Wyszukiwanie …",
    "Start typing to search" : "Zacznij pisać, aby wyszukać",
    "Minimum search length is {minSearchLength} characters" : "Minimalna długość wyszukiwania to {minSearchLength} znaków",
    "No matching results" : "Brak pasujących wyników",
    "Today" : "Dzisiaj",
    "Last 7 days" : "Ostatnie 7 dni",
    "Last 30 days" : "Ostatnie 30 dni",
    "This year" : "W tym roku",
    "Last year" : "W zeszłym roku",
    "Between {startDate} and {endDate}" : "Pomiędzy {startDate} a {endDate}",
    "Unified search" : "Ujednolicone wyszukiwanie",
    "Search apps, files, tags, messages" : "Szukaj aplikacji, plików, tagów, wiadomości",
    "Places" : "Miejsca",
    "Date" : "Data",
    "Search people" : "Szukaj ludzi",
    "People" : "Osoby",
    "Filter in current view" : "Filtruj w bieżącym widoku",
    "Search connected services" : "Szukaj połączonych usług",
    "Results" : "Wyniki",
    "Load more results" : "Wczytaj więcej wyników",
    "Search in" : "Szukaj w",
    "Partial matches" : "Częściowe dopasowania",
    "Log in" : "Zaloguj",
    "Logging in …" : "Logowanie ...",
    "Log in to {productName}" : "Zaloguj się do {productName}",
    "Wrong login or password." : "Błędny login lub hasło.",
    "This account is disabled" : "To konto jest wyłączone",
    "Too many incorrect login attempts. Please try again in 30 seconds." : "Zbyt wiele nieprawidłowych prób logowania. Spróbuj ponownie za 30 sekund.",
    "Account name or email" : "Nazwa konta lub e-mail",
    "Account name" : "Nazwa konta",
    "Server side authentication failed!" : "Uwierzytelnianie po stronie serwera nie powiodło się!",
    "Please contact your administrator." : "Skontaktuj się z administratorem",
    "Session error" : "Błąd sesji",
    "It appears your session token has expired, please refresh the page and try again." : "Wygląda na to, że Twój token sesji wygasł. Odśwież stronę i spróbuj ponownie.",
    "An internal error occurred." : "Wystąpił błąd wewnętrzny.",
    "Please try again or contact your administrator." : "Spróbuj ponownie lub skontaktuj się z administratorem.",
    "Password" : "Hasło",
    "Remember me" : "Zapamiętaj mnie",
    "Log in with a device" : "Zaloguj się za pomocą urządzenia",
    "Login or email" : "Nazwa logowania lub e-mail",
    "Your account is not setup for passwordless login." : "Twoje konto nie jest skonfigurowane do logowania bez hasła.",
    "Your connection is not secure" : "Twoje połączenie nie jest bezpieczne",
    "Passwordless authentication is only available over a secure connection." : "Uwierzytelnianie bez hasła jest dostępne tylko przez bezpieczne połączenie.",
    "Browser not supported" : "Przeglądarka nie jest obsługiwana",
    "Passwordless authentication is not supported in your browser." : "Uwierzytelnianie bez hasła nie jest obsługiwane w przeglądarce.",
    "Reset password" : "Zresetuj hasło",
    "Back to login" : "Powrót do logowania",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Jeśli to konto istnieje, wiadomość dotycząca resetowania hasła została wysłana na jego adres e-mail. Jeśli go nie otrzymasz, zweryfikuj swój adres e-mail i/lub nazwę logowania, sprawdź katalogi ze spamem/śmieciami lub poproś o pomoc lokalną administrację.",
    "Couldn't send reset email. Please contact your administrator." : "Nie mogę wysłać e-maila resetującego hasło. Skontaktuj się z administratorem.",
    "Password cannot be changed. Please contact your administrator." : "Hasło nie może zostać zmienione. Skontaktuj się z administratorem.",
    "New password" : "Nowe hasło",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Twoje pliki są szyfrowane. Po zresetowaniu hasła nie będzie możliwości odzyskania danych. Jeśli nie masz pewności, co zrobić, skontaktuj się z administratorem przed kontynuowaniem. Czy na pewno chcesz kontynuować?",
    "I know what I'm doing" : "Wiem co robię",
    "Resetting password" : "Resetowanie hasła",
    "Schedule work & meetings, synced with all your devices." : "Zaplanuj pracę i spotkania, które będą zsynchronizowane ze wszystkimi urządzeniami.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Przechowuj swoich kolegów i przyjaciół w jednym miejscu, nie udostępniając prywatnych informacji.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Prosta aplikacja e-mail przyjemnie zintegrowana z plikami, kontaktami i kalendarzem.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Czaty, rozmowy wideo, udostępnianie ekranu, spotkania online i konferencje internetowe – w przeglądarce i aplikacjach mobilnych.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Wspólne dokumenty, arkusze kalkulacyjne i prezentacje oparte na Collabora Online.",
    "Distraction free note taking app." : "Aplikacja do robienia notatek bez rozpraszania uwagi.",
    "Recommended apps" : "Polecane aplikacje",
    "Loading apps …" : "Wczytywanie aplikacji …",
    "Could not fetch list of apps from the App Store." : "Nie można pobrać listy aplikacji ze sklepu z aplikacjami.",
    "App download or installation failed" : "Pobieranie lub instalacja aplikacji nie powiodła się",
    "Cannot install this app because it is not compatible" : "Nie można zainstalować tej aplikacji, ponieważ nie jest kompatybilna",
    "Cannot install this app" : "Nie można zainstalować tej aplikacji",
    "Skip" : "Pomiń",
    "Installing apps …" : "Instalowanie aplikacji …",
    "Install recommended apps" : "Zainstaluj zalecane aplikacje",
    "Online" : "Online",
    "Away" : "Bezczynny",
    "Busy" : "Brak dostępności",
    "Do not disturb" : "Nie przeszkadzać",
    "Mute all notifications" : "Wycisz wszystkie powiadomienia",
    "Invisible" : "Niewidoczny",
    "Appear offline" : "Wyglądaj jako offline",
    "Avatar of {displayName}" : "Awatar {displayName}",
    "Settings menu" : "Menu ustawień",
    "Loading your contacts …" : "Wczytywanie kontaktów …",
    "Looking for {term} …" : "Szukam {term} …",
    "Search contacts" : "Szukaj kontaktów",
    "Filter by team" : "Filtruj według zespołu",
    "All teams" : "Wszystkie zespoły",
    "Search contacts in team {team}" : "Szukaj kontaktów w zespole {team}",
    "Search contacts …" : "Wyszukiwanie kontaktów …",
    "Reset search" : "Zresetuj wyszukiwanie",
    "Could not load your contacts" : "Nie można wczytać kontaktów",
    "No contacts found" : "Nie znaleziono kontaktów",
    "Contacts list" : "Lista kontaktów",
    "Show all contacts" : "Pokaż wszystkie kontakty",
    "Install the Contacts app" : "Zainstaluj aplikację \"Kontakty\"",
    "Search" : "Szukaj",
    "No results for {query}" : "Brak wyników dla {query}",
    "Press Enter to start searching" : "Naciśnij Enter, aby rozpocząć wyszukiwanie",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Aby wyszukać, wprowadź co najmniej {minSearchLength} znak","Aby wyszukać, wprowadź co najmniej {minSearchLength} znaki","Aby wyszukać, wprowadź co najmniej {minSearchLength} znaków","Aby wyszukać, wprowadź co najmniej {minSearchLength} znaków"],
    "An error occurred while searching for {type}" : "Wystąpił błąd podczas wyszukiwania {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Wyszukiwanie rozpoczyna się po rozpoczęciu pisania, a wyniki można uzyskać za pomocą klawiszy strzałek",
    "Search for {name} only" : "Wyszukaj tylko {name}",
    "Loading more results …" : "Wczytuję więcej wyników …",
    "Forgot password?" : "Zapomniałeś hasła?",
    "Back to login form" : "Powrót do formularza logowania",
    "Back" : "Wstecz",
    "Login form is disabled." : "Formularz logowania jest wyłączony.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Formularz logowania Nextcloud jest wyłączony. Użyj innej opcji logowania, jeśli jest dostępna, lub skontaktuj się z administracją.",
    "Connect to your account" : "Połącz z kontem",
    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Zaloguj się, zanim przyznasz klientowi \"{client}\" dostęp do konta {instanceName}.",
    "Security warning" : "Ostrzeżenie bezpieczeństwa",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jeśli nie konfigurujesz nowego urządzenia lub aplikacji, to wynika z tego, że ktoś próbuje, abyś udzielił dostępu do Twoich danych. W takim przypadku nie kontynuuj, tylko skontaktuj się z administratorem systemu.",
    "Log in using password" : "Zaloguj się przy użyciu hasła",
    "Alternative log in using app password" : "Alternatywne logowanie przy użyciu hasła do aplikacji",
    "Account connected" : "Połączono z kontem",
    "Your client should now be connected!" : "Twój klient powinien być teraz podłączony!",
    "You can close this window." : "Możesz zamknąć to okno.",
    "Account access" : "Dostęp do konta",
    "Currently logged in as {userDisplayName} ({userId})." : "Aktualnie zalogowany jako {userDisplayName} ({userId}).",
    "You are about to grant \"{client}\" access to your {instanceName} account." : "Zamierzasz przyznać klientowi \"{client}\" dostęp do konta {instanceName}.",
    "More actions" : "Więcej akcji",
    "User menu" : "Menu użytkownika",
    "Your guest name: {user}" : "Twoja nazwa gościa: {user}",
    "You are currently not identified." : "Obecnie nie jesteś zidentyfikowany.",
    "Set public name" : "Ustaw nazwę publiczną",
    "Change public name" : "Zmień nazwę publiczną",
    "This share is password-protected" : "Udostępnienie jest zabezpieczone hasłem",
    "The password is wrong or expired. Please try again or request a new one." : "Hasło jest nieprawidłowe lub wygasło. Spróbuj ponownie lub poproś o nowe.",
    "Submit" : "Wyślij",
    "Please type in your email address to request a temporary password" : "Wpisz swój adres e-mail, aby poprosić o tymczasowe hasło",
    "Password sent!" : "Hasło wysłane!",
    "You are not authorized to request a password for this share" : "Nie masz uprawnień do żądania hasła dla tego udostępnienia",
    "Email address" : "Adres e-mail",
    "Request password" : "Żądanie hasła",
    "Forgot password" : "Zapomniałeś hasła?",
    "Password is too weak" : "Hasło jest za słabe",
    "Password is weak" : "Hasło jest słabe",
    "Password is average" : "Hasło jest przeciętne",
    "Password is strong" : "Hasło jest silne",
    "Password is very strong" : "Hasło jest bardzo silne",
    "Password is extremely strong" : "Hasło jest niezwykle silne",
    "Unknown password strength" : "Nieznana siła hasła",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Prawdopodobnie Twój katalog danych i pliki są dostępne z Internetu, ponieważ plik <code>.htaccess</code> nie działa.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Aby uzyskać informacje na temat prawidłowej konfiguracji serwera, {linkStart}zapoznaj się z dokumentacją{linkEnd}",
    "Autoconfig file detected" : "Wykryto plik autokonfiguracjny",
    "The setup form below is pre-filled with the values from the config file." : "Poniższy formularz konfiguracji jest wstępnie wypełniony wartościami z pliku konfiguracyjnego.",
    "Create administration account" : "Utwórz konto administracyjne",
    "Administration account name" : "Nazwa konta administracyjnego",
    "Administration account password" : "Hasło do konta administracyjnego",
    "Storage & database" : "Magazyn i baza danych",
    "Data folder" : "Katalog danych",
    "Database configuration" : "Konfiguracja bazy danych",
    "Database type" : "Typ bazy danych",
    "Only {firstAndOnlyDatabase} is available." : "Dostępne jest tylko {firstAndOnlyDatabase}.",
    "Install and activate additional PHP modules to choose other database types." : "Zainstaluj lub aktywuj dodatkowe moduły PHP, aby uzyskać możliwość wyboru innych typów baz danych.",
    "For more details check out the documentation." : "Aby uzyskać więcej informacji zapoznaj się z dokumentacją.",
    "Performance warning" : "Ostrzeżenie o wydajności",
    "You chose SQLite as database." : "Wybrałeś SQLite jako bazę danych.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite powinien być używany tylko dla instancji minimalnych i rozwojowych. Dla rozwiniętej zalecamy inne zaplecze bazy danych.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jeśli używasz klientów do synchronizacji plików, używanie SQLite jest bardzo odradzane.",
    "Database connection" : "Połączenie bazy danych",
    "Database user" : "Użytkownik bazy danych",
    "Database password" : "Hasło do bazy danych",
    "Database name" : "Nazwa bazy danych",
    "Database tablespace" : "Obszar tabel bazy danych",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Podaj numer portu wraz z nazwą hosta (np. localhost: 5432).",
    "Database host" : "Host bazy danych",
    "localhost" : "localhost",
    "Installing …" : "Instalowanie …",
    "Install" : "Zainstaluj",
    "Need help?" : "Potrzebujesz pomocy?",
    "See the documentation" : "Zapoznaj się z dokumentacją",
    "{name} version {version} and above" : "{name} wersja {version} i nowsze",
    "This browser is not supported" : "Ta przeglądarka nie jest obsługiwana",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Twoja przeglądarka nie jest wspierana. Uaktualnij do nowszej lub obsługiwanej wersji.",
    "Continue with this unsupported browser" : "Kontynuuj w tej nieobsługiwanej przeglądarce",
    "Supported versions" : "Obsługiwane wersje",
    "The update completed with warnings. Please check the details for more information." : "Aktualizacja zakończona z ostrzeżeniami. Sprawdź szczegóły, aby uzyskać więcej informacji.",
    "The update completed successfully." : "Aktualizacja zakończona pomyślnie.",
    "Preparing update…" : "Przygotowywanie aktualizacji…",
    "You will be redirected to {productName} in {count} seconds." : "Za {count} sekund nastąpi przekierowanie do {productName}",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Trwa aktualizacja. W niektórych przypadkach, opuszczenie tej strony może przerwać ten proces.",
    "App update required" : "Wymagana aktualizacja aplikacji",
    "{productName} will be updated to version {version}" : "{productName} zostanie zaktualizowany do wersji {version}",
    "The theme {oldTheme} has been disabled." : "Motyw {oldTheme} został wyłączony.",
    "These incompatible apps will be disabled:" : "Niekompatybilne aplikacje zostaną wyłączone:",
    "Incompatible apps" : "Niekompatybilne aplikacje",
    "These apps will be updated:" : "Następujące aplikacje zostaną zaktualizowane:",
    "Apps to update" : "Aplikacje do aktualizacji",
    "{app} from {oldVersion} to {version}" : "{app} z {oldVersion} do {version}",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Przed kontynuowaniem upewnij się, że utworzono kopię zapasową bazy danych, katalogu konfiguracyjnego i katalogu danych.",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "W przypadku większych instalacji, aby uniknąć przekroczenia limitu czasu, możesz zamiast tego instalatora uruchomić następujące polecenie z katalogu instalacyjnego:",
    "Start update" : "Rozpocznij aktualizację",
    "Continue to {productName}" : "Przejdź do {productName}",
    "Update to {version}" : "Aktualizacja do {version}",
    "Hide details" : "Ukryj szczegóły",
    "Show details" : "Pokaż szczegóły",
    "Update details" : "Szczegóły aktualizacji",
    "Update needed" : "Wymagana aktualizacja",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Użyj aktualizatora z wiersza poleceń, ponieważ masz dużą instancję z ponad 50 kontami.",
    "Documentation" : "Dokumentacja",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Wiem, że jeśli kontynuuję aktualizację za pomocą przeglądarki, istnieje ryzyko że operacja może nie wykonać się w określonym limicie czasu, co może doprowadzić do utraty danych, ale mam kopię zapasową i wiem jak przywrócić w przypadku niepowodzenia.",
    "Upgrade via web on my own risk" : "Wykonaj aktualizację poprzez przeglądarkę na własne ryzyko",
    "Search {types} …" : "Wyszukaj {types} …",
    "Choose {file}" : "Wybierz {file}",
    "Choose" : "Wybierz",
    "Copy to {target}" : "Skopiuj do {target}",
    "Copy" : "Kopiuj",
    "Move to {target}" : "Przenieś do {target}",
    "Move" : "Przenieś",
    "OK" : "OK",
    "read-only" : "tylko odczyt",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} konflikt pliku","{count} konflikty pliku","{count} konfliktów pliku","{count} konfliktów pliku"],
    "One file conflict" : "Konflikt pliku",
    "New Files" : "Nowe pliki",
    "Already existing files" : "Już istniejące pliki",
    "Which files do you want to keep?" : "Które pliki chcesz zachować?",
    "If you select both versions, the copied file will have a number added to its name." : "Jeśli wybierzesz obie wersje, to do nazwy skopiowanego pliku zostanie dodany numer.",
    "Cancel" : "Anuluj",
    "Continue" : "Kontynuuj",
    "(all selected)" : "(wybrano wszystkie)",
    "({count} selected)" : "(wybrano {count})",
    "Error loading file exists template" : "Błąd podczas ładowania pliku istniejącego szablonu",
    "Saving …" : "Zapisywanie…",
    "Groups" : "Grupy",
    "Group list is empty" : "Lista grup jest pusta",
    "Unable to retrieve the group list" : "Nie można pobrać listy grup",
    "seconds ago" : "przed chwilą",
    "Add to a project" : "Dodaj do projektu",
    "Rename project" : "Zmień nazwę projektu",
    "Failed to rename the project" : "Nie można zmienić nazwy projektu",
    "Failed to create a project" : "Nie udało się utworzyć projektu",
    "Failed to add the item to the project" : "Nie udało się dodać elementu do projektu",
    "Connect items to a project to make them easier to find" : "Połącz elementy z projektem, aby łatwiej je znaleźć",
    "Type to search for existing projects" : "Wpisz rodzaj, aby wyszukać istniejące projekty",
    "Close \"{dialogTitle}\" dialog" : "Zamknij okno \"{dialogTitle}\"",
    "Email length is at max (255)" : "Długość e-maila jest maksymalna (255)",
    "Clipboard not available, please copy manually" : "Schowek nie jest dostępny, prosimy skopiować ręcznie",
    "Personal" : "Osobiste",
    "Accounts" : "Konta",
    "Admin" : "Administrator",
    "Help" : "Pomoc",
    "Access forbidden" : "Dostęp zabroniony",
    "You are not allowed to access this page." : "Nie masz uprawnień do tej strony.",
    "Back to %s" : "Powrót do %s",
    "Page not found" : "Nie znaleziono strony",
    "The page could not be found on the server or you may not be allowed to view it." : "Strona nie została znaleziona na serwerze lub możesz nie mieć uprawnień do jej przeglądania.",
    "Too many requests" : "Zbyt wiele żądań",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zbyt wiele żądań z Twojej sieci. Spróbuj ponownie później lub skontaktuj się z administratorem, jeśli jest to błąd.",
    "Error" : "Błąd",
    "Internal Server Error" : "Błąd wewnętrzny serwera",
    "The server was unable to complete your request." : "Serwer nie mógł zakończyć żądania.",
    "If this happens again, please send the technical details below to the server administrator." : "Jeśli to się powtórzy, prześlij poniższe szczegóły techniczne do administratora serwera.",
    "More details can be found in the server log." : "Więcej szczegółów można znaleźć w logu serwera.",
    "For more details see the documentation ↗." : "Więcej szczegółów znajdziesz w dokumentacji ↗.",
    "Technical details" : "Szczegóły techniczne",
    "Remote Address: %s" : "Adres zdalny: %s",
    "Request ID: %s" : "ID żądania: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "Komunikat: %s",
    "File: %s" : "Plik: %s",
    "Line: %s" : "Linia: %s",
    "Trace" : "Ślad",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Wygląda na to, że próbujesz ponownie zainstalować Nextcloud. Brakuje jednak pliku CAN_INSTALL w katalogu konfiguracyjnym. Aby kontynuować, utwórz plik CAN_INSTALL w katalogu konfiguracyjnym.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nie można usunąć CAN_INSTALL z katalogu konfiguracyjnego. Usuń ten plik ręcznie.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikacja do poprawnego działania wymaga JavaScript. {linkstart}włącz JavaScript{linkend} i wczytaj stronę ponownie.",
    "Skip to main content" : "Przejdź do głównej zawartości",
    "Skip to navigation of app" : "Przejdź do nawigacji aplikacji",
    "Go to %s" : "Przejdź do %s",
    "Get your own free account" : "Załóż własne bezpłatne konto",
    "Previous" : "Poprzedni",
    "Two-factor authentication" : "Uwierzytelnianie dwuskładnikowe",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Dodatkowe zabezpieczenia są włączone dla Twojego konta. Wybierz drugą metodę uwierzytelniania:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nie można załadować co najmniej jednej z włączonych dwuskładnikowych metod uwierzytelnienia. Skontaktuj się z administratorem.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Uwierzytelnianie dwuskładnikowe jest wymuszone, ale nie zostało skonfigurowane na Twoim koncie. Skontaktuj się z administratorem, aby uzyskać pomoc.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Uwierzytelnianie dwuskładnikowe jest wymuszane, ale nie zostało skonfigurowane na Twoim koncie. Kontynuuj konfigurację uwierzytelniania dwuskładnikowego.",
    "Set up two-factor authentication" : "Skonfiguruj uwierzytelnianie dwuskładnikowe",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Uwierzytelnianie dwuskładnikowe jest wymuszone, ale nie zostało skonfigurowane na Twoim koncie. Użyj jednego z kodów zapasowych, aby się zalogować lub skontaktuj się z administratorem w celu uzyskania pomocy.",
    "Use backup code" : "Użyj kodu zapasowego",
    "Cancel login" : "Anuluj logowanie",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Dla Twojego konta zwiększono zabezpieczenie. Wybierz dostawcę, którego chcesz skonfigurować:",
    "Error while validating your second factor" : "Błąd podczas sprawdzania drugiego składnika",
    "Access through untrusted domain" : "Dostęp przez niezaufaną domenę",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Skontaktuj się z administratorem. Jeśli jesteś administratorem, edytuj ustawienie \"trusted_domains\" w config/config.php, tak jak w przykładzie config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Więcej informacji na temat konfiguracji można znaleźć w %1$sdokumentacji%2$s.",
    "Maintenance mode" : "Tryb konserwacji",
    "This %s instance is currently in maintenance mode, which may take a while." : "Ta instancja %s jest obecnie w trybie konserwacji, co może chwilę potrwać.",
    "This page will refresh itself when the instance is available again." : "Strona odświeży się, gdy instancja będzie ponownie dostępna.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Skontaktuj się z administratorem systemu, jeśli ten komunikat będzie się powtarzał lub pojawił się nieoczekiwanie.",
    "Error occurred while checking server setup" : "Wystąpił błąd podczas sprawdzania konfiguracji serwera",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Więcej informacji można znaleźć w {linkstart}dokumentacji ↗{linkend}.",
    "unknown text" : "nieznany tekst",
    "Hello world!" : "Witaj świecie!",
    "sunny" : "słoneczna",
    "Hello {name}, the weather is {weather}" : "Cześć {name}, dzisiejsza pogoda jest {weather}",
    "Hello {name}" : "Witaj {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>To są twoje wyniki wyszukiwania<script>alert(1)</script></strong>",
    "new" : "nowy",
    "_download %n file_::_download %n files_" : ["pobrano %n plik","pobrano %n pliki","pobrano %n plików","pobrano %n plików"],
    "An error occurred." : "Wystąpił błąd.",
    "Please reload the page." : "Przeładuj stronę.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizacja nie powiodła się. Aby uzyskać więcej informacji, <a href=\"{url}\">zapoznaj się z naszym postem na forum</a> dotyczącym tego problemu.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizacja nie powiodła się. Zgłoś ten problem do <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">społeczności Nextcloud</a>.",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekundę.","Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekundy.","Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekund.","Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekund."],
    "Direct link copied to clipboard" : "Bezpośredni odnośnik skopiowany do schowka",
    "Searching …" : "Wyszukiwanie…",
    "Logging in …" : "Logowanie…",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Wykryliśmy wiele nieudanych prób logowania z Twojego adresu IP. Dlatego następne logowanie będzie możliwe dopiero za 30 sekund.",
    "Loading apps …" : "Wczytywanie aplikacji…",
    "Installing apps …" : "Instalowanie aplikacji…",
    "Loading your contacts …" : "Wczytywanie kontaktów…",
    "Looking for {term} …" : "Szukam {term}…",
    "Search contacts …" : "Wyszukiwanie kontaktów…",
    "Loading more results …" : "Wczytuję więcej wyników…",
    "Search {types} …" : "Wyszukaj {types}…",
    "Saving …" : "Zapisywanie…",
    "Connection to server lost" : "Utracono połączenie z serwerem",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem z wczytaniem strony, ponowne wczytanie za %n sekundę","Problem z wczytaniem strony, ponowne wczytanie za %n sekundy","Problem z wczytaniem strony, ponowne wczytanie za %n sekund","Problem z wczytaniem strony, ponowne wczytanie za %n sekund"],
    "New in" : "Nowość w",
    "View changelog" : "Przeglądaj listę zmian",
    "Very weak password" : "Bardzo słabe hasło",
    "Weak password" : "Słabe hasło",
    "So-so password" : "Mało skomplikowane hasło",
    "Good password" : "Dobre hasło",
    "Strong password" : "Silne hasło",
    "No action available" : "Żadna akcja nie jest dostępna",
    "Error fetching contact actions" : "Błąd podczas pobierania akcji dla kontaktu",
    "Non-existing tag #{tag}" : "Etykieta #{tag} nie istnieje",
    "Restricted" : "Ograniczone",
    "Delete" : "Usuń",
    "Rename" : "Zmień nazwę",
    "Collaborative tags" : "Etykiety wspólne",
    "No tags found" : "Nie znaleziono etykiet",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Twój katalog danych i pliki są prawdopodobnie dostępne z poziomu internetu, ponieważ plik .htaccess nie działa.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informacje na temat prawidłowej konfiguracji serwera można znaleźć w <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentacji</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Utwórz konto administratora</strong>",
    "New admin account name" : "Nowa nazwa konta administratora",
    "New admin password" : "Nowe hasło administratora",
    "Show password" : "Pokaż hasło",
    "Toggle password visibility" : "Przełącz widoczność hasła",
    "Configure the database" : "Skonfiguruj bazę danych",
    "Only %s is available." : "Dostępne jest tylko %s.",
    "Database account" : "Konto bazy danych",
    "Installing …" : "Instalowanie…",
    "Please log in before granting %1$s access to your %2$s account." : "Zaloguj się przed udzieleniem dostępu %1$s do swojego konta %2$s.",
    "Currently logged in as %1$s (%2$s)." : "Aktualnie zalogowany jako %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Zamierzasz udzielić dostępu do swojego konta %2$s dla %1$s.",
    "%1$s will be updated to version %2$s" : "%1$s zostanie zaktualizowany do wersji %2$s",
    "The following apps will be updated:" : "Następujące aplikacje zostaną zaktualizowane:",
    "The theme %s has been disabled." : "Motyw %s został wyłączony.",
    "Detailed logs" : "Szczegółowe logi",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Aby uzyskać pomoc, zajrzyj do <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentacji</a>."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
